@@ -15,7 +15,7 @@ class WebNovelData(Database):
         self.pending = MultiClassTable(self.db, 'pending', Chapter, ['index', 'no', 'url'], 'url')
         self.chapters = MultiClassExternalTable(
             self.db, self.path.parent, 'chapters', Chapter,
-            ['index', 'no', 'title', 'paragraphs', 'url'], 'url',
+            ['index', 'no', 'title', 'paragraphs', 'url'], ['index'], 'url',
             naming_scheme=lambda c: str(c.index),
             on_missing=lambda c: self.pending.put(c),
         )
