@@ -1,6 +1,6 @@
 from .source import Source
 from .boxnovel import BoxNovel
-# from .scribblehub import ScribbleHub
+from .scribblehub import ScribbleHub
 from .insanitycave import InsanityCave
 from .kieshitl import KieshiTl
 from .ktlchamber import Ktlchamber
@@ -8,6 +8,8 @@ from .lightnovelworld import LightNovelWorld
 from .readlightnovel import ReadLightNovel
 from .webnovel import Webnovel
 from .wuxiaco import WuxiaCo
+from .mtlnovel import MtlNovel
+from .fanfiction import Fanfiction
 
 sources = [
     WuxiaCo,
@@ -16,5 +18,8 @@ sources = [
     InsanityCave,
     Ktlchamber,
     LightNovelWorld,
-    KieshiTl
+    KieshiTl,
+    ScribbleHub,
+    MtlNovel,
+    Fanfiction
 ]
\ No newline at end of file
