@@ -7,11 +7,11 @@ from ..tools import StringTools
 
 
 class BoxNovel(Source):
-    base = 'https://boxnovel.com'
+    base = 'https://boxnovel.com/'
 
     @staticmethod
     def of(url: str) -> bool:
-        return url[:len(BoxNovel.base)] == BoxNovel.base
+        return StringTools.startswith(url, BoxNovel.base)
 
     def novel(self, url: str) -> Tuple[Novel, List[Chapter]]:
         soup = self.soup(url)
@@ -29,7 +29,8 @@ class BoxNovel(Source):
         )
 
         chapters = []
-        for i, element in enumerate(soup.find_all('li', {'class': 'wp-manga-chapter'})):
+        chapter_elements = soup.find_all('li', {'class': 'wp-manga-chapter'})
+        for i, element in enumerate(reversed(chapter_elements)):
             title_element = element.find('a')
 
             no, title = self._parse_title(title_element.text.strip())
