@@ -47,4 +47,8 @@ class UiTools:
 
     @staticmethod
     def print_var(name, value):
-        print(f'[-] {name} = {value}')
\ No newline at end of file
+        print(f'[-] {name} = {value}')
+
+    @staticmethod
+    def print_info(*args):
+        print('[-]', *args)
